import html from './template.html'
import axios from 'axios'
import apiUrls from 'common/api-urls'
import formValidate from 'utils/form-validate'

export default {
  template: html,
  props: {
    maxTime: {
      type: Number,
      default: 120
    },
    phone: {
      type: String,
      default: ''
    },
    isRegister: {
      type: Boolean,
      default: false
    }
  },

  data() {
    return {
      isDisabled: false,
      isGettingCode: false,
      countDownNo: 0,
      timer: 0,
      code: ''
    }
  },

  methods: {
    $getCode() {
      if (this.phone && formValidate.phone(this.phone)) {
        this.mobileExist()
      } else {
        this.$toast({
          message: '请输入正确的手机号码',
          duration: 3000,
          className: 'mint-toast-width'
        })
      }
    },

    mobileExist() {
      axios.get(apiUrls.mobileExist + '?mobile=' + this.phone)
        .then((res) => {
          if (this.isRegister) {
            if (res.data) {
              this.$toast({
                message: res.detailMessage || res.message,
                duration: 3000,
                className: 'mint-toast-width'
              })
            } else {
              this.getCode()
            }
          } else {
            if (!res.data) {
              this.$toast({
                message: '手机号码未注册',
                duration: 3000,
                className: 'mint-toast-width'
              })
            } else {
              this.getCode()
            }
          }
        })
        .catch((err) => {
          this.$getCodeFailed(err)
        })
    },

    getCode() {
      axios.post(apiUrls.getCode + '?mobile=' + this.phone).then((res) => {
        this.$getCodeSuccess(res)
      }, (error) => {
        this.$getCodeFailed(error)
      }).catch((error) => {
        this.$getCodeFailed(error)
      })
    },

    $getCodeSuccess(res) {
      this.$emit('uniqueId', res.data)
      this.isDisabled = true
      this.countDownNo = this.maxTime
      this.$triggerTime()
      if (this.getCodeCb && typeof this.getCodeCb === 'function') {
        this.getCodeCb(this.code)
      }
    },

    $getCodeFailed(error) {
      this.isDisabled = false
      this.$toast({
        message: error.message || error,
        duration: 3000,
        className: 'mint-toast-width'
      })
    },

    $triggerTime() {
      clearInterval(this.timer)
      this.timer = setInterval(() => {
        if (this.countDownNo <= 1) {
          clearInterval(this.timer)
          this.isDisabled = false
          this.countDownNo = this.maxTime
        } else {
          this.countDownNo--
        }
      }, 1000)
    }
  }
}
