import html from './template.html'
import models from './models'
import ResetPassWord from 'components/reset-pass-word'
import UserRegister from 'components/user-register'
import Dialog from 'components/dialog'

export default {
  template: html,
  data() {
    return {
      userName: '',
      password: '',
      validateCode: '',
      isPopShow: false,
      isShowRigister: false,
      isShowResetPW: false,

      regUname: '',
      regPwd: '',
      regCode: '',

      rpwdUname: '',
      rpwdPwd: '',
      rpwdCode: ''
    }
  },
  props: {
    loginShow: {
      type: Boolean,
      required: true,
      default: false
    },
    needRegister: {
      type: Boolean,
      required: true,
      default: false
    },
    closeCb: {
      type: Function
    },
    loginSuccessCb: {
      type: Function
    }
  },

  computed: {},

  components: {
    'reset-pass-word': ResetPassWord,
    'pop-dialog': Dialog,
    'user-register': UserRegister
  },

  methods: {
    $closePanel() {
      if (this.closeCb && typeof this.closeCb === 'function') {
        this.closeCb()
      }
    },

    $doLogin() {
      let validRes = models.doValidate(this)
      if (validRes === true) {
        this.$indicator.open({
          spinnerType: 'fading-circle'
        })

        models.doLogin(this, this.$loginSuccess.bind(this), this.$loginFaild.bind(this))
      }
    },

    $loginSuccess() {
      this.$indicator.close()

      if (this.loginSuccessCb && typeof this.loginSuccessCb === 'function') {
        this.loginSuccessCb()
      }
    },

    $loginFaild() {
      this.$indicator.close()
    },

    backToLogin() {
      this.isPopShow = true
      this.isShowResetPW = false
      this.isShowRigister = false
      this.loginShow = true
    },

    $doRegister() {
      this.isPopShow = true
      this.isShowResetPW = false
      this.isShowRigister = true
      this.loginShow = false
    },

    $doGetPassBack() {
      this.isPopShow = true
      this.isShowResetPW = true
      this.isShowRigister = false
      this.loginShow = false
    },

    getPassSuccessCb() {
      this.$registOrRestSuccess('密码重置成功')
    },
    registerSuccessCb() {
      this.$registOrRestSuccess('注册成功')
    },

    $registOrRestSuccess(msg) {
      let time,
        pageMethod

      time = 3000
      pageMethod = this.$store.state.loginMethod // 0 page 1 pop dialog

      this.closePopCb()
      this.$toast({
        message: msg,
        iconClass: 'fr-iconfont icon-radio-check-s',
        duration: time
      })

      if (pageMethod !== 1) {
        setTimeout(() => {
          window.location.href = '/'
        }, time)
      } else {
        this.$loginSuccess()
      }
    },

    closePopCb() {
      this.isPopShow = false
      this.isShowResetPW = false
      this.isShowRigister = false
      // models.resetStoreForLogin(this)
      // models.clearQueue()

      if (this.closeCb && typeof this.closeCb === 'function') {
        this.closeCb()
      }
    }
  }
}
