import axios from 'axios'
import apiUrls from 'common/api-urls'
import auth from 'common/auth'
import storage from 'common/storage'
import { SET_USER_INFO, SET_USER_LOGIN_STATUS } from 'store/mutation-types'
import formValidate from 'utils/form-validate'
import axioDecorate from 'common/axio-decorate'

import Base64 from 'utils/base64'

export default {
  doValidate(_this) {
    let msg,
      res

    res = true

    if (formValidate.phone(_this.userName) === false) {
      msg = '请输入正确的手机号'
      res = false
    } else if (formValidate.password(_this.password, 6, 15) === false) {
      msg = '请输入正确的密码'
      res = false
    }

    if (res === false) {
      _this.$toast({
        message: msg,
        duration: 10000,
        className: 'mint-toast-width'
      })
    }

    return res
  },

  doLogin(_this, successCb, failedCb) {
    let params

    params = {
      userCode: _this.userName,
      userPassword: Base64.encode(_this.password)
    }

    axios.post(apiUrls.userLogin, params)
      .then((res) => {
        let loginToken
        // TODO need uptimize
        loginToken = res.data
        auth.setTokenToCookie(loginToken)
        axios.defaults.headers.loginToken = loginToken
        this.getCurrentUserInfo(_this, loginToken, successCb, failedCb)
      })
      .catch((error) => {
        this.loginFailed(_this, error, failedCb)
      })
  },

  loginFailed(_this, error, failedCb) {
    console.error(error)
    this.showMsg(_this, error.detailMessage || error.message || error, 'fr-iconfont icon-info', 'mint-toast-width')
    if (failedCb && typeof failedCb === 'function') {
      failedCb()
    }
  },

  getCurrentUserInfo(_this, loginToken, successCb, failedCb) {
    auth.setTokenToCookie(loginToken)
    axios.defaults.headers.loginToken = loginToken
    axios.post(apiUrls.getCurrentUserInfo).then((res) => {
      this.saveUserInfoToStore(_this, loginToken, res.data)
      _this.password = ''
      if (successCb && typeof successCb === 'function') {
        successCb()
      }
    }, (error) => {
      this.loginFailed(_this, error, failedCb)
    }).catch((error) => {
      this.loginFailed(_this, error, failedCb)
    })
  },

  saveUserInfoToStore(_this, loginToken, res) {
    let newUserInfo

    // newUserInfo = {
    //   id: res[0].id,
    //   userId: res[0].phone,
    //   accountName: res[0].userId,
    //   name: _this.userName,
    //   phone: res[0].phone,
    //   openId: res[0].openId,
    //   unionId: res[0].unionId,
    //   userPwd: res[0].userPwd,
    //   loginToken: res[1].loginToken
    // }

    newUserInfo = {
      id: res.userIdStr,
      userId: res.userIdStr,
      accountName: res.userName,
      name: _this.userName,
      phone: res.mobile,
      unionId: res.unionId,
      loginToken: loginToken
    }

    _this.$store.commit(SET_USER_INFO, newUserInfo)
    _this.$store.commit(SET_USER_LOGIN_STATUS, true)
    auth.setTokenToCookie(loginToken)
    storage.setUserInfoToStorage(newUserInfo)
    axioDecorate.setHttpHeaderCookie()
  },

  showMsg(_this, msg, icon, css) {
    _this.$toast({
      message: msg,
      duration: 3000,
      className: css || '',
      iconClass: icon
    })
  },

  getListSonArea(areaCode) {}
}
